@@ -1,5 +1,5 @@
 #
-# $Id: Libdnet.pm 44 2011-01-14 10:25:07Z gomor $
+# $Id: Libdnet.pm 54 2011-11-14 21:59:34Z gomor $
 #
 # Copyright (c) 2004 Vlad Manilici
 # Copyright (c) 2008-2011 Patrice <GomoR> Auffret
@@ -33,7 +33,7 @@ use strict; use warnings;
 
 use base qw(Exporter DynaLoader);
 
-our $VERSION = '0.95';
+our $VERSION = '0.96';
 
 our %EXPORT_TAGS = (
    obsolete => [qw(
@@ -138,6 +138,13 @@ our @EXPORT = (
 
 __PACKAGE__->bootstrap($VERSION);
 
+our $Dnet6Support = 0;
+
+eval("use Net::Libdnet6;");
+if (!$@) {
+   $Dnet6Support++;
+}
+
 use constant DNET_ADDR_TYPE_NONE => 0;
 use constant DNET_ADDR_TYPE_ETH  => 1;
 use constant DNET_ADDR_TYPE_IP   => 2;
